@@ -33,7 +33,7 @@ The input L</url> to given as argument to the plugin need to point to a
 valid L<swagger|https://github.com/swagger-api/swagger-spec/blob/master/versions/2.0.md>
 document.
 
-Note that every operation must have a "x-mojo-controller" specified,
+Every operation must have a "x-mojo-controller" specified,
 so this plugin knows where to look for the decamelized "operationId",
 which is used as method name.
 
@@ -44,6 +44,7 @@ which is used as method name.
     /foo:
       get:
         x-mojo-controller: MyApp::Controller::Api
+        x-mojo-around-action: MyApp::authenticate_api_request
         operationId: listPets
         parameters: [ ... ]
         responses:
@@ -74,8 +75,8 @@ agent.
   package MyApp::Controller::Api;
 
   sub list_pets {
-    my ($c, $args, $cb) = @_;
-    $c->$cb({ foo => 123 }, 200);
+    my ($c, $input, $cb) = @_;
+    $c->$cb({foo => 123}, 200);
   }
 
 =head2 Protected API
@@ -121,6 +122,32 @@ L<relaxed placeholder|https://metacpan.org/pod/distribution/Mojolicious/lib/Mojo
         responses:
           200: { ... }
 
+=head2 Around action hook
+
+The C<x-mojo-around-action> value is optional, but can hold the name of a
+method to call, which wraps around the autogenerated action which does input
+and output validation. This means that any data sent to the server is not
+yet converted into C<$input> to your action.
+
+Here is an example method which match the C<x-mojo-around-action> from
+L</Swagger specification>, C<MyApp::authenticate_api_request>:
+
+  package MyApp;
+
+  sub authenticate_api_request {
+    my ($next, $c, $action_spec) = @_;
+
+    # Go to the action if the Authorization header is valid
+    return $next->($c) if $c->req->headers->authorization eq "s3cret!";
+
+    # ...or render an error if not
+    return $c->render_swagger(
+      {errors => [{message => "Invalid authorization key", path => "/"}]},
+      {},
+      401
+    );
+  }
+
 =cut
 
 use Mojo::Base 'Mojolicious::Plugin';
@@ -319,6 +346,15 @@ sub _generate_request_handler {
     $defaults->{$p->{name}} = $p->{default} if $p->{in} eq 'path' and defined $p->{default};
   }
 
+  if (my $around_action = $config->{'x-mojo-around-action'}) {
+    my $next = $handler;
+    $handler = sub {
+      my $c = shift;
+      my $around = $c->can($around_action) || $around_action;
+      $around->($next, $c, $config);
+    };
+  }
+
   return $defaults, $handler;
 }
 
